@@ -12,7 +12,9 @@ import dgl
 import numpy as np
 import pandas as pd
 from jarvis.core.atoms import Atoms
-from jarvis.core.graphs import Graph, StructureDataset
+from alignn.graphs import Graph, StructureDataset
+
+# from jarvis.core.graphs import Graph, StructureDataset
 from jarvis.db.figshare import data as jdata
 from torch.utils.data import DataLoader
 from tqdm import tqdm
@@ -55,7 +57,7 @@ def load_dataset(
     d = data
     if limit is not None:
         d = d[:limit]
-    d = pd.DataFrame(d)
+    # d = pd.DataFrame(d)
     # d = d.replace("na", np.nan)
     return d
 
@@ -67,7 +69,7 @@ def mean_absolute_deviation(data, axis=None):
 
 
 def load_graphs(
-    df: pd.DataFrame,
+    dataset=[],
     name: str = "dft_3d",
     neighbor_strategy: str = "k-nearest",
     cutoff: float = 8,
@@ -108,6 +110,8 @@ def load_graphs(
     if cachefile is not None and cachefile.is_file():
         graphs, labels = dgl.load_graphs(str(cachefile))
     else:
+        df = pd.DataFrame(dataset)
+
         graphs = df["atoms"].progress_apply(atoms_to_graph).values
         if cachefile is not None:
             dgl.save_graphs(str(cachefile), graphs.tolist())
@@ -176,6 +180,9 @@ def get_torch_dataset(
     dataset=[],
     id_tag="jid",
     target="",
+    target_atomwise="",
+    target_grad="",
+    target_stress="",
     neighbor_strategy="",
     atom_features="",
     use_canonize="",
@@ -189,8 +196,9 @@ def get_torch_dataset(
 ):
     """Get Torch Dataset."""
     df = pd.DataFrame(dataset)
-    # print("df", df)
-    vals = df[target].values
+    # df['natoms']=df['atoms'].apply(lambda x: len(x['elements']))
+    # print(" data df", df)
+    vals = np.array([ii[target] for ii in dataset])  # df[target].values
     print("data range", np.max(vals), np.min(vals))
     f = open(os.path.join(output_dir, tmp_name + "_data_range"), "w")
     line = "Max=" + str(np.max(vals)) + "\n"
@@ -207,11 +215,13 @@ def get_torch_dataset(
         cutoff=cutoff,
         max_neighbors=max_neighbors,
     )
-
     data = StructureDataset(
         df,
         graphs,
         target=target,
+        target_atomwise=target_atomwise,
+        target_grad=target_grad,
+        target_stress=target_stress,
         atom_features=atom_features,
         line_graph=line_graph,
         id_tag=id_tag,
@@ -224,6 +234,9 @@ def get_train_val_loaders(
     dataset: str = "dft_3d",
     dataset_array=[],
     target: str = "formation_energy_peratom",
+    target_atomwise: str = "",
+    target_grad: str = "",
+    target_stress: str = "",
     atom_features: str = "cgcnn",
     neighbor_strategy: str = "k-nearest",
     n_train=None,
@@ -447,6 +460,9 @@ def get_train_val_loaders(
             id_tag=id_tag,
             atom_features=atom_features,
             target=target,
+            target_atomwise=target_atomwise,
+            target_grad=target_grad,
+            target_stress=target_stress,
             neighbor_strategy=neighbor_strategy,
             use_canonize=use_canonize,
             name=dataset,
@@ -462,6 +478,9 @@ def get_train_val_loaders(
             id_tag=id_tag,
             atom_features=atom_features,
             target=target,
+            target_atomwise=target_atomwise,
+            target_grad=target_grad,
+            target_stress=target_stress,
             neighbor_strategy=neighbor_strategy,
             use_canonize=use_canonize,
             name=dataset,
@@ -477,6 +496,9 @@ def get_train_val_loaders(
             id_tag=id_tag,
             atom_features=atom_features,
             target=target,
+            target_atomwise=target_atomwise,
+            target_grad=target_grad,
+            target_stress=target_stress,
             neighbor_strategy=neighbor_strategy,
             use_canonize=use_canonize,
             name=dataset,
@@ -489,6 +511,7 @@ def get_train_val_loaders(
         )
 
         collate_fn = train_data.collate
+        # print("line_graph,line_dih_graph", line_graph, line_dih_graph)
         if line_graph:
             collate_fn = train_data.collate_line_graph
 
